@@ -24,6 +24,7 @@ from mapproxy.config.loader import (
     merge_dict,
     ConfigurationError,
 )
+from mapproxy.config.spec import validate_options
 from mapproxy.cache.tile import TileManager
 from mapproxy.test.helper import TempFile
 from mapproxy.test.unit.test_grid import assert_almost_equal_bbox
@@ -235,6 +236,8 @@ class TestLayerConfiguration(object):
 
     def test_without_sources_or_layers(self):
         conf = self._test_conf('''
+            services:
+                wms:
             layers:
               title: Root Layer
               layers:
@@ -242,12 +245,14 @@ class TestLayerConfiguration(object):
                   title: Layer One
         ''')
         conf = ProxyConfiguration(conf)
+        assert conf.wms_root_layer.wms_layer() == None
         try:
-            conf.wms_root_layer.wms_layer()
-        except ValueError:
+            conf.services.services()
+        except ConfigurationError:
+            # found no WMS layer
             pass
         else:
-            assert False, 'expected ValueError'
+            assert False, 'expected ConfigurationError'
 
 
 class TestGridConfiguration(object):
@@ -512,6 +517,35 @@ class TestWMSSourceConfiguration(object):
             raise SkipTest('no ssl support')
 
 
+class TestBandMergeConfig(object):
+
+    def test_invalid_band(self):
+        conf_dict = {
+            'caches': {
+                'osm': {
+                    'sources': {'f': [{'source': 'foo', 'band': 1}]},
+                    'grids': ['GLOBAL_WEBMERCATOR'],
+                }
+            }
+        }
+        errors, informal_only = validate_options(conf_dict)
+        eq_(len(errors), 1)
+        assert "unknown 'f' in caches" in errors[0]
+
+    def test_no_band_cache(self):
+        conf_dict = {
+            'caches': {
+                'osm': {
+                    'sources': {'l': [{'source': 'foo'}]},
+                    'grids': ['GLOBAL_WEBMERCATOR'],
+                }
+            }
+        }
+        errors, informal_only = validate_options(conf_dict)
+        eq_(len(errors), 1)
+        assert "missing 'band', not in caches" in errors[0], errors
+
+
 def load_services(conf_file):
     conf = load_configuration(conf_file)
     return conf.configured_services()
